Class: Yt::VideoAudit::VideoEndScreen
- Defined in:
- lib/yt/video_audit/video_end_screen.rb
Overview
Count how many subject videos have an end screens with a video link.
Instance Method Summary collapse
Methods inherited from Base
#initialize, #total_count, #valid_count
Constructor Details
This class inherits a constructor from Yt::VideoAudit::Base
Instance Method Details
#description ⇒ Object
12 13 14 |
# File 'lib/yt/video_audit/video_end_screen.rb', line 12 def description 'The number of videos with any link to a video in its end screens' end |
#title ⇒ Object
8 9 10 |
# File 'lib/yt/video_audit/video_end_screen.rb', line 8 def title 'Video End Screens' end |